==> v1.4.0.zip: ssgf_utils/weipinshang_api/res.go <==
package weipinshang_api

type GetManyPostageRes struct {
	Code int         `json:"code"` // 0为成功，其它为失败
	Msg  string      `json:"msg"`  // 请求接口消息
	Data FreightData `json:"data"` //  返回数据	data		array
}
type FreightData struct {
	Freight string `json:"freight"` // 	邮费	freight	是	string		邮费
}

type PreOrderRes struct {
	Code int                 `json:"code"` // 0为成功，其它为失败
	Msg  string              `json:"msg"`  // 请求接口消息
	Data PreOrderFreightData `json:"data"` //  返回数据	data		array
}
type PreOrderFreightData struct {
	Freight     string `json:"freight"`      // 	邮费	freight	是	string		邮费
	FreightDesc string `json:"freight_desc"` // 	邮费说明	freight_desc	是	string		邮费说明
}

type CreateOrderRes struct {
	Code int               `json:"code"` // 0为成功，其它为失败
	Msg  string            `json:"msg"`  // 请求接口消息
	Data []CreateOrderData `json:"data"` //  返回数据	data		array
}
type CreateOrderData struct {
	ThirdOrderNo string    `json:"thirdOrderNo"` //  第三方订单号 本地订单号
	OrderNo      string    `json:"orderNo"`      //   主订单号
	McOrderNo    string    `json:"mcOrderNo"`    //蜜仓子订单号
	OrderAmount  float64   `json:"orderAmount"`  // 	子订单总金额
	Sku          []SkuData `json:"sku"`          // 订单商品信息
}

type SkuData struct {
	GoodSpecId string      `json:"goodSpecId"` //商品ID(c_goods_id)
	GoodsId    string      `json:"goodsId"`    //商品ID(c_father_goods_id)
	GoodName   string      `json:"goodName"`   //商品名称
	Num        interface{} `json:"num"`        //数量
	//Num   int    `json:"num"`   //数量
	Price string `json:"price"` //单价
}

type GetOrderInfoRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
	Data []Data `json:"data"` //  返回数据	data		array
}
type Data struct {
	CThirdUserCode string `json:"c_third_user_code"` // 用户编码
	//COrderNoThird      string  `json:"c_order_no_third"`      // 渠道订单号
	COrderNo           string  `json:"c_order_no"`            // 渠道订单号
	COrderNoPayservice string  `json:"c_order_no_payservice"` //支付订单号
	CSendStatus        string  `json:"c_send_status"`         //  订单状态 订单所处阶段【’’CHECKED订单被创建’’,’INSTOCK已备货’,’’SENDED已发货’’,’’RECEIVED已收货’’】
	CIsPay             int     `json:"c_is_pay"`              // 支付状态(0-未支付，1-已支付)
	CIsClose           int     `json:"c_is_close"`            // 关闭状态	c_is_close				是否关闭【0未关闭，1,已经关闭】
	CShouldPay         float64 `json:"c_should_pay"`          // 订单应付金额 单位：元
	CRealPay           float64 `json:"c_real_pay"`            //  实际支付金额	c_real_pay				单位：元
	CMessage           string  `json:"c_message"`             // 订单留言
	CComment           string  `json:"c_comment"`             //  系统操作备注
	CDeliveryName      string  `json:"c_delivery_name"`       //  快递公司
	CDeliveryNo        string  `json:"c_delivery_no"`         //  快递单号
	CCreateDatetime    string  `json:"c_create_datetime"`     // 订单创建时间
	CPayDatetime       string  `json:"c_pay_datetime"`        // 订单支付时间
	CSendDatetime      string  `json:"c_send_datetime"`       //  订单发货时间
	CReceiveDatetime   string  `json:"c_receive_datetime"`    //  订单确认收货时间
	CReceiverName      string  `json:"c_receiver_name"`       //  收货人姓名
	CReceiverMobile    string  `json:"c_receiver_mobile"`     //  收货人联系方式
}

type GetOrderInfoByItemNORes struct {
	Code int                   `json:"code"` // 0为成功，其它为失败
	Msg  string                `json:"msg"`  // 请求接口消息
	Data OrderInfoByItemNOData `json:"data"` //  返回数据	data		array

}
type OrderInfoByItemNOData struct {
	OrderItemNo  string `json:"order_item_no"` //  子订单号
	SendStatus   string `json:"send_status"`   //发货状态【’CHECKED订单被创建’,’INSTOCK已备货’,’SENDED已发货’,’RECEIVED已收货’】
	DeliveryName string `json:"delivery_name"` //  快递公司
	DeliveryNo   string `json:"delivery_no"`   //  快递单号
	RefuseStatus string `json:"refuse_status"` //售后状态【CREATED 创建售后单’,’ALLOW同意’,’SUCCESS成功’,’NOTALLOW拒绝’,’MONEY_RETURNED已操作退款’,’FAIL_RETURNED退款失败,线下退款’】
	RefuseType   string `json:"refuse_type"`   // 售后类型【’RETURN_MONEY 退款’,’RETURN_GOODS 退货’】
}

type GetOrderInfoByThirdNORes struct {
	Code int             `json:"code"` // 0为成功，其它为失败
	Msg  string          `json:"msg"`  // 请求接口消息
	Data []OrderInfoData `json:"data"` //  返回数据	data		array
}
type OrderInfoData struct {
	GoodsId      string `json:"goodsId"`       //商品ID	goodsId	是	String		商品父ID(c_father_goods_id)
	GoodSpecId   string `json:"goodSpecId"`    //SKU ID	goodSpecId	是	String		商品ID(c_goods_id)
	OrderItemNo  string `json:"order_item_no"` //  子订单号
	SendStatus   string `json:"send_status"`   //发货状态【’CHECKED订单被创建’,’INSTOCK已备货’,’SENDED已发货’,’RECEIVED已收货’】
	DeliveryName string `json:"delivery_name"` //  快递公司
	DeliveryNo   string `json:"delivery_no"`   //  快递单号
}

type IsRefundRes struct {
	Code int          `json:"code"` // 0为成功，其它为失败
	Msg  string       `json:"msg"`  // 请求接口消息
	Data IsRefundData `json:"data"` //  返回数据	data		array

}

type IsRefundData struct {
	ResultType []Param `json:"resultType"` // 售后类型
	WareReturn []Param `json:"wareReturn"` //  服务类型
}

type Param struct {
	Code int    `json:"code"` // 服务类型码 4	[上门取件(4)、客户发货(40)、客户送货(7)]
	Name string `json:"name"` // 服务类型名称 上门取件	[上门取件、客户发货、客户送货]
}

type CreateAfsApplyRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
	Type string `json:"type"` // wait 等待。return_money：已退款
}

type OrderCancelRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
}

type RefundDeliveryRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
}

// test -------------------------------------

type TestRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
}

==> v1.8.2.zip: ssgf_utils/weipinshang_api/res.go <==
package weipinshang_api

type GetManyPostageRes struct {
	Code int         `json:"code"` // 0为成功，其它为失败
	Msg  string      `json:"msg"`  // 请求接口消息
	Data FreightData `json:"data"` //  返回数据	data		array
}
type FreightData struct {
	Freight string `json:"freight"` // 	邮费	freight	是	string		邮费
}

type PreOrderRes struct {
	Code int                 `json:"code"` // 0为成功，其它为失败
	Msg  string              `json:"msg"`  // 请求接口消息
	Data PreOrderFreightData `json:"data"` //  返回数据	data		array
}
type PreOrderFreightData struct {
	Freight     string `json:"freight"`      // 	邮费	freight	是	string		邮费
	FreightDesc string `json:"freight_desc"` // 	邮费说明	freight_desc	是	string		邮费说明
}

type CreateOrderRes struct {
	Code int               `json:"code"` // 0为成功，其它为失败
	Msg  string            `json:"msg"`  // 请求接口消息
	Data []CreateOrderData `json:"data"` //  返回数据	data		array
}
type CreateOrderData struct {
	ThirdOrderNo string      `json:"thirdOrderNo"` //  第三方订单号 本地订单号
	OrderNo      string      `json:"orderNo"`      //   主订单号
	McOrderNo    string      `json:"mcOrderNo"`    //蜜仓子订单号
	OrderAmount  interface{} `json:"orderAmount"`  // 	子订单总金额
	Sku          []SkuData   `json:"sku"`          // 订单商品信息
}

type SkuData struct {
	GoodSpecId string      `json:"goodSpecId"` //商品ID(c_goods_id)
	GoodsId    string      `json:"goodsId"`    //商品ID(c_father_goods_id)
	GoodName   string      `json:"goodName"`   //商品名称
	Num        interface{} `json:"num"`        //数量
	//Num   int    `json:"num"`   //数量
	Price interface{} `json:"price"` //单价
}

type GetOrderInfoRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
	Data []Data `json:"data"` //  返回数据	data		array
}
type Data struct {
	CThirdUserCode string `json:"c_third_user_code"` // 用户编码
	//COrderNoThird      string  `json:"c_order_no_third"`      // 渠道订单号
	COrderNo           string  `json:"c_order_no"`            // 渠道订单号
	COrderNoPayservice string  `json:"c_order_no_payservice"` //支付订单号
	CSendStatus        string  `json:"c_send_status"`         //  订单状态 订单所处阶段【’’CHECKED订单被创建’’,’INSTOCK已备货’,’’SENDED已发货’’,’’RECEIVED已收货’’】
	CIsPay             int     `json:"c_is_pay"`              // 支付状态(0-未支付，1-已支付)
	CIsClose           int     `json:"c_is_close"`            // 关闭状态	c_is_close				是否关闭【0未关闭，1,已经关闭】
	CShouldPay         float64 `json:"c_should_pay"`          // 订单应付金额 单位：元
	CRealPay           float64 `json:"c_real_pay"`            //  实际支付金额	c_real_pay				单位：元
	CMessage           string  `json:"c_message"`             // 订单留言
	CComment           string  `json:"c_comment"`             //  系统操作备注
	CDeliveryName      string  `json:"c_delivery_name"`       //  快递公司
	CDeliveryNo        string  `json:"c_delivery_no"`         //  快递单号
	CCreateDatetime    string  `json:"c_create_datetime"`     // 订单创建时间
	CPayDatetime       string  `json:"c_pay_datetime"`        // 订单支付时间
	CSendDatetime      string  `json:"c_send_datetime"`       //  订单发货时间
	CReceiveDatetime   string  `json:"c_receive_datetime"`    //  订单确认收货时间
	CReceiverName      string  `json:"c_receiver_name"`       //  收货人姓名
	CReceiverMobile    string  `json:"c_receiver_mobile"`     //  收货人联系方式
}

type GetOrderInfoByItemNORes struct {
	Code int                   `json:"code"` // 0为成功，其它为失败
	Msg  string                `json:"msg"`  // 请求接口消息
	Data OrderInfoByItemNOData `json:"data"` //  返回数据	data		array

}
type OrderInfoByItemNOData struct {
	OrderItemNo  string `json:"order_item_no"` //  子订单号
	SendStatus   string `json:"send_status"`   //发货状态【’CHECKED订单被创建’,’INSTOCK已备货’,’SENDED已发货’,’RECEIVED已收货’】
	DeliveryName string `json:"delivery_name"` //  快递公司
	DeliveryNo   string `json:"delivery_no"`   //  快递单号
	RefuseStatus string `json:"refuse_status"` //售后状态【CREATED 创建售后单’,’ALLOW同意’,’SUCCESS成功’,’NOTALLOW拒绝’,’MONEY_RETURNED已操作退款’,’FAIL_RETURNED退款失败,线下退款’】
	RefuseType   string `json:"refuse_type"`   // 售后类型【’RETURN_MONEY 退款’,’RETURN_GOODS 退货’】
}

type GetOrderInfoByThirdNORes struct {
	Code int             `json:"code"` // 0为成功，其它为失败
	Msg  string          `json:"msg"`  // 请求接口消息
	Data []OrderInfoData `json:"data"` //  返回数据	data		array
}
type OrderInfoData struct {
	GoodsId      string `json:"goodsId"`       //商品ID	goodsId	是	String		商品父ID(c_father_goods_id)
	GoodSpecId   string `json:"goodSpecId"`    //SKU ID	goodSpecId	是	String		商品ID(c_goods_id)
	OrderItemNo  string `json:"order_item_no"` //  子订单号
	SendStatus   string `json:"send_status"`   //发货状态【’CHECKED订单被创建’,’INSTOCK已备货’,’SENDED已发货’,’RECEIVED已收货’】
	DeliveryName string `json:"delivery_name"` //  快递公司
	DeliveryNo   string `json:"delivery_no"`   //  快递单号
}

type IsRefundRes struct {
	Code int          `json:"code"` // 0为成功，其它为失败
	Msg  string       `json:"msg"`  // 请求接口消息
	Data IsRefundData `json:"data"` //  返回数据	data		array

}

type IsRefundData struct {
	ResultType []Param `json:"resultType"` // 售后类型
	WareReturn []Param `json:"wareReturn"` //  服务类型
}

type Param struct {
	Code int    `json:"code"` // 服务类型码 4	[上门取件(4)、客户发货(40)、客户送货(7)]
	Name string `json:"name"` // 服务类型名称 上门取件	[上门取件、客户发货、客户送货]
}

type CreateAfsApplyRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
	Type string `json:"type"` // wait 等待。return_money：已退款
}

type OrderCancelRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
}

type RefundDeliveryRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
}

// test -------------------------------------

type TestRes struct {
	Code int    `json:"code"` // 0为成功，其它为失败
	Msg  string `json:"msg"`  // 请求接口消息
}
